# coding: utf-8

# flake8: noqa
from __future__ import absolute_import

# import models
from groupdocs_signature_cloud.models.barcode_type import BarcodeType
from groupdocs_signature_cloud.models.barcodes_result import BarcodesResult
from groupdocs_signature_cloud.models.base_settings import BaseSettings
from groupdocs_signature_cloud.models.border_line import BorderLine
from groupdocs_signature_cloud.models.brush import Brush
from groupdocs_signature_cloud.models.color import Color
from groupdocs_signature_cloud.models.consumption_result import ConsumptionResult
from groupdocs_signature_cloud.models.delete_options import DeleteOptions
from groupdocs_signature_cloud.models.delete_result import DeleteResult
from groupdocs_signature_cloud.models.disc_usage import DiscUsage
from groupdocs_signature_cloud.models.error import Error
from groupdocs_signature_cloud.models.error_details import ErrorDetails
from groupdocs_signature_cloud.models.file_info import FileInfo
from groupdocs_signature_cloud.models.file_versions import FileVersions
from groupdocs_signature_cloud.models.files_list import FilesList
from groupdocs_signature_cloud.models.files_upload_result import FilesUploadResult
from groupdocs_signature_cloud.models.format import Format
from groupdocs_signature_cloud.models.formats_result import FormatsResult
from groupdocs_signature_cloud.models.info_result import InfoResult
from groupdocs_signature_cloud.models.object_exist import ObjectExist
from groupdocs_signature_cloud.models.options_base import OptionsBase
from groupdocs_signature_cloud.models.padding import Padding
from groupdocs_signature_cloud.models.page_info import PageInfo
from groupdocs_signature_cloud.models.pages_setup import PagesSetup
from groupdocs_signature_cloud.models.pdf_digital_signature import PdfDigitalSignature
from groupdocs_signature_cloud.models.preview_page import PreviewPage
from groupdocs_signature_cloud.models.preview_result import PreviewResult
from groupdocs_signature_cloud.models.qr_code_type import QRCodeType
from groupdocs_signature_cloud.models.qr_codes_result import QRCodesResult
from groupdocs_signature_cloud.models.save_options import SaveOptions
from groupdocs_signature_cloud.models.search_result import SearchResult
from groupdocs_signature_cloud.models.sign_result import SignResult
from groupdocs_signature_cloud.models.signature import Signature
from groupdocs_signature_cloud.models.signature_appearance import SignatureAppearance
from groupdocs_signature_cloud.models.signature_font import SignatureFont
from groupdocs_signature_cloud.models.stamp_line import StampLine
from groupdocs_signature_cloud.models.storage_exist import StorageExist
from groupdocs_signature_cloud.models.storage_file import StorageFile
from groupdocs_signature_cloud.models.time_stamp import TimeStamp
from groupdocs_signature_cloud.models.update_options import UpdateOptions
from groupdocs_signature_cloud.models.update_result import UpdateResult
from groupdocs_signature_cloud.models.verify_result import VerifyResult
from groupdocs_signature_cloud.models.barcode_signature import BarcodeSignature
from groupdocs_signature_cloud.models.delete_settings import DeleteSettings
from groupdocs_signature_cloud.models.digital_signature import DigitalSignature
from groupdocs_signature_cloud.models.digital_signature_appearance import DigitalSignatureAppearance
from groupdocs_signature_cloud.models.file_version import FileVersion
from groupdocs_signature_cloud.models.form_field_signature import FormFieldSignature
from groupdocs_signature_cloud.models.image_appearance import ImageAppearance
from groupdocs_signature_cloud.models.image_signature import ImageSignature
from groupdocs_signature_cloud.models.info_settings import InfoSettings
from groupdocs_signature_cloud.models.linear_gradient_brush import LinearGradientBrush
from groupdocs_signature_cloud.models.pdf_digital_signature_appearance import PdfDigitalSignatureAppearance
from groupdocs_signature_cloud.models.pdf_text_annotation_appearance import PdfTextAnnotationAppearance
from groupdocs_signature_cloud.models.pdf_text_sticker_appearance import PdfTextStickerAppearance
from groupdocs_signature_cloud.models.preview_settings import PreviewSettings
from groupdocs_signature_cloud.models.qr_code_signature import QRCodeSignature
from groupdocs_signature_cloud.models.radial_gradient_brush import RadialGradientBrush
from groupdocs_signature_cloud.models.search_options import SearchOptions
from groupdocs_signature_cloud.models.search_settings import SearchSettings
from groupdocs_signature_cloud.models.sign_options import SignOptions
from groupdocs_signature_cloud.models.sign_settings import SignSettings
from groupdocs_signature_cloud.models.solid_brush import SolidBrush
from groupdocs_signature_cloud.models.text_signature import TextSignature
from groupdocs_signature_cloud.models.texture_brush import TextureBrush
from groupdocs_signature_cloud.models.update_settings import UpdateSettings
from groupdocs_signature_cloud.models.verify_options import VerifyOptions
from groupdocs_signature_cloud.models.verify_settings import VerifySettings
from groupdocs_signature_cloud.models.checkbox_form_field_signature import CheckboxFormFieldSignature
from groupdocs_signature_cloud.models.combobox_form_field_signature import ComboboxFormFieldSignature
from groupdocs_signature_cloud.models.digital_form_field_signature import DigitalFormFieldSignature
from groupdocs_signature_cloud.models.radio_button_form_field_signature import RadioButtonFormFieldSignature
from groupdocs_signature_cloud.models.search_barcode_options import SearchBarcodeOptions
from groupdocs_signature_cloud.models.search_digital_options import SearchDigitalOptions
from groupdocs_signature_cloud.models.search_qr_code_options import SearchQRCodeOptions
from groupdocs_signature_cloud.models.sign_image_options import SignImageOptions
from groupdocs_signature_cloud.models.sign_text_options import SignTextOptions
from groupdocs_signature_cloud.models.text_form_field_signature import TextFormFieldSignature
from groupdocs_signature_cloud.models.verify_digital_options import VerifyDigitalOptions
from groupdocs_signature_cloud.models.verify_text_options import VerifyTextOptions
from groupdocs_signature_cloud.models.sign_barcode_options import SignBarcodeOptions
from groupdocs_signature_cloud.models.sign_digital_options import SignDigitalOptions
from groupdocs_signature_cloud.models.sign_qr_code_options import SignQRCodeOptions
from groupdocs_signature_cloud.models.sign_stamp_options import SignStampOptions
from groupdocs_signature_cloud.models.verify_barcode_options import VerifyBarcodeOptions
from groupdocs_signature_cloud.models.verify_qr_code_options import VerifyQRCodeOptions



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="test_auth_api.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest
import warnings

import six

from groupdocs_signature_cloud import InfoApi, Configuration, ApiException
from test.test_settings import TestSettings

class TestAuthApi(unittest.TestCase):
    """SignatureApi unit tests"""

    def setUp(self):
        if six.PY3:
            warnings.simplefilter("ignore", ResourceWarning)

    def init_signature_api(self, app_sid, app_key):
        configuration = Configuration(app_sid, app_key)
        configuration.api_base_url = TestSettings.API_BASE_URL
        
        return InfoApi.from_config(configuration)

    def test_auth_error_when_app_sid_not_found(self):
        """Test case to check handling of authentication errors"""
        
        app_sid = "test"
        app_key = "test"
        
        info_api = self.init_signature_api(app_sid, app_key)

        with self.assertRaises(ApiException) as context:
            info_api.get_supported_file_formats()

        self.assertEqual("invalid_client", context.exception.message)
    
    def test_auth_error_when_app_key_not_found(self):
        """Test case to check handling of authentication errors"""
        
        app_sid = TestSettings.APP_SID
        app_key = "test"
        
        info_api = self.init_signature_api(app_sid, app_key)

        with self.assertRaises(ApiException) as context:
            info_api.get_supported_file_formats()

        self.assertEqual("invalid_client", context.exception.message)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="VerifyDigitalOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import VerifyOptions

class VerifyDigitalOptions(VerifyOptions):
    """
    Defines options to verify Digital signature within a document
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'password': 'str',
        'certificate_file_path': 'str',
        'comments': 'str',
        'sign_date_time_from': 'datetime',
        'sign_date_time_to': 'datetime',
        'reason': 'str',
        'contact': 'str',
        'location': 'str'
    }

    attribute_map = {
        'password': 'Password',
        'certificate_file_path': 'CertificateFilePath',
        'comments': 'Comments',
        'sign_date_time_from': 'SignDateTimeFrom',
        'sign_date_time_to': 'SignDateTimeTo',
        'reason': 'Reason',
        'contact': 'Contact',
        'location': 'Location'
    }

    def __init__(self, password=None, certificate_file_path=None, comments=None, sign_date_time_from=None, sign_date_time_to=None, reason=None, contact=None, location=None, **kwargs):  # noqa: E501
        """Initializes new instance of VerifyDigitalOptions"""  # noqa: E501

        self._password = None
        self._certificate_file_path = None
        self._comments = None
        self._sign_date_time_from = None
        self._sign_date_time_to = None
        self._reason = None
        self._contact = None
        self._location = None

        if password is not None:
            self.password = password
        if certificate_file_path is not None:
            self.certificate_file_path = certificate_file_path
        if comments is not None:
            self.comments = comments
        if sign_date_time_from is not None:
            self.sign_date_time_from = sign_date_time_from
        if sign_date_time_to is not None:
            self.sign_date_time_to = sign_date_time_to
        if reason is not None:
            self.reason = reason
        if contact is not None:
            self.contact = contact
        if location is not None:
            self.location = location

        base = super(VerifyDigitalOptions, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def password(self):
        """
        Gets the password.  # noqa: E501

        Password of Digital Certificate if required  # noqa: E501

        :return: The password.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password.

        Password of Digital Certificate if required  # noqa: E501

        :param password: The password.  # noqa: E501
        :type: str
        """
        self._password = password
    
    @property
    def certificate_file_path(self):
        """
        Gets the certificate_file_path.  # noqa: E501

        File Guid of Digital Certificate  # noqa: E501

        :return: The certificate_file_path.  # noqa: E501
        :rtype: str
        """
        return self._certificate_file_path

    @certificate_file_path.setter
    def certificate_file_path(self, certificate_file_path):
        """
        Sets the certificate_file_path.

        File Guid of Digital Certificate  # noqa: E501

        :param certificate_file_path: The certificate_file_path.  # noqa: E501
        :type: str
        """
        self._certificate_file_path = certificate_file_path
    
    @property
    def comments(self):
        """
        Gets the comments.  # noqa: E501

        Comments of Digital Signature to validate Suitable for Spreadsheet and Words Processing document types  # noqa: E501

        :return: The comments.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments.

        Comments of Digital Signature to validate Suitable for Spreadsheet and Words Processing document types  # noqa: E501

        :param comments: The comments.  # noqa: E501
        :type: str
        """
        self._comments = comments
    
    @property
    def sign_date_time_from(self):
        """
        Gets the sign_date_time_from.  # noqa: E501

        Date and time range of Digital Signature to validate. Null value will be ignored. Suitable for Spreadsheet and Words Processing document types  # noqa: E501

        :return: The sign_date_time_from.  # noqa: E501
        :rtype: datetime
        """
        return self._sign_date_time_from

    @sign_date_time_from.setter
    def sign_date_time_from(self, sign_date_time_from):
        """
        Sets the sign_date_time_from.

        Date and time range of Digital Signature to validate. Null value will be ignored. Suitable for Spreadsheet and Words Processing document types  # noqa: E501

        :param sign_date_time_from: The sign_date_time_from.  # noqa: E501
        :type: datetime
        """
        self._sign_date_time_from = sign_date_time_from
    
    @property
    def sign_date_time_to(self):
        """
        Gets the sign_date_time_to.  # noqa: E501

        Date and time range of Digital Signature to validate. Null value will be ignored Suitable for Spreadsheet and Words Processing document types  # noqa: E501

        :return: The sign_date_time_to.  # noqa: E501
        :rtype: datetime
        """
        return self._sign_date_time_to

    @sign_date_time_to.setter
    def sign_date_time_to(self, sign_date_time_to):
        """
        Sets the sign_date_time_to.

        Date and time range of Digital Signature to validate. Null value will be ignored Suitable for Spreadsheet and Words Processing document types  # noqa: E501

        :param sign_date_time_to: The sign_date_time_to.  # noqa: E501
        :type: datetime
        """
        self._sign_date_time_to = sign_date_time_to
    
    @property
    def reason(self):
        """
        Gets the reason.  # noqa: E501

        Reason of Digital Signature to validate Suitable for Pdf document type  # noqa: E501

        :return: The reason.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason.

        Reason of Digital Signature to validate Suitable for Pdf document type  # noqa: E501

        :param reason: The reason.  # noqa: E501
        :type: str
        """
        self._reason = reason
    
    @property
    def contact(self):
        """
        Gets the contact.  # noqa: E501

        Signature Contact to validate Suitable for Pdf document type  # noqa: E501

        :return: The contact.  # noqa: E501
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact.

        Signature Contact to validate Suitable for Pdf document type  # noqa: E501

        :param contact: The contact.  # noqa: E501
        :type: str
        """
        self._contact = contact
    
    @property
    def location(self):
        """
        Gets the location.  # noqa: E501

        Signature Location to validate Suitable for Pdf document type  # noqa: E501

        :return: The location.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location.

        Signature Location to validate Suitable for Pdf document type  # noqa: E501

        :param location: The location.  # noqa: E501
        :type: str
        """
        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VerifyDigitalOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="PreviewSettings.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import BaseSettings

class PreviewSettings(BaseSettings):
    """
    Defines preview request settings
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'width': 'int',
        'height': 'int',
        'page_numbers': 'list[int]',
        'preview_format': 'str',
        'hide_signatures': 'bool',
        'output_path': 'str'
    }

    attribute_map = {
        'width': 'Width',
        'height': 'Height',
        'page_numbers': 'PageNumbers',
        'preview_format': 'PreviewFormat',
        'hide_signatures': 'HideSignatures',
        'output_path': 'OutputPath'
    }

    def __init__(self, width=None, height=None, page_numbers=None, preview_format=None, hide_signatures=None, output_path=None, **kwargs):  # noqa: E501
        """Initializes new instance of PreviewSettings"""  # noqa: E501

        self._width = None
        self._height = None
        self._page_numbers = None
        self._preview_format = None
        self._hide_signatures = None
        self._output_path = None

        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if page_numbers is not None:
            self.page_numbers = page_numbers
        if preview_format is not None:
            self.preview_format = preview_format
        if hide_signatures is not None:
            self.hide_signatures = hide_signatures
        if output_path is not None:
            self.output_path = output_path

        base = super(PreviewSettings, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def width(self):
        """
        Gets the width.  # noqa: E501

        Preview images width  # noqa: E501

        :return: The width.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width.

        Preview images width  # noqa: E501

        :param width: The width.  # noqa: E501
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501
        self._width = width
    
    @property
    def height(self):
        """
        Gets the height.  # noqa: E501

        Preview images height  # noqa: E501

        :return: The height.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height.

        Preview images height  # noqa: E501

        :param height: The height.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501
        self._height = height
    
    @property
    def page_numbers(self):
        """
        Gets the page_numbers.  # noqa: E501

        Preview page numbers  # noqa: E501

        :return: The page_numbers.  # noqa: E501
        :rtype: list[int]
        """
        return self._page_numbers

    @page_numbers.setter
    def page_numbers(self, page_numbers):
        """
        Sets the page_numbers.

        Preview page numbers  # noqa: E501

        :param page_numbers: The page_numbers.  # noqa: E501
        :type: list[int]
        """
        self._page_numbers = page_numbers
    
    @property
    def preview_format(self):
        """
        Gets the preview_format.  # noqa: E501

        Preview format  # noqa: E501

        :return: The preview_format.  # noqa: E501
        :rtype: str
        """
        return self._preview_format

    @preview_format.setter
    def preview_format(self, preview_format):
        """
        Sets the preview_format.

        Preview format  # noqa: E501

        :param preview_format: The preview_format.  # noqa: E501
        :type: str
        """
        if preview_format is None:
            raise ValueError("Invalid value for `preview_format`, must not be `None`")  # noqa: E501
        allowed_values = ["PNG", "JPEG", "BMP"]  # noqa: E501
        if not preview_format.isdigit():	
            if preview_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `preview_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(preview_format, allowed_values))
            self._preview_format = preview_format
        else:
            self._preview_format = allowed_values[int(preview_format) if six.PY3 else long(preview_format)]
    
    @property
    def hide_signatures(self):
        """
        Gets the hide_signatures.  # noqa: E501

        Flag to hide signatures from page preview image. Only signatures are marked as IsSignature will be hidden from generated document page image  # noqa: E501

        :return: The hide_signatures.  # noqa: E501
        :rtype: bool
        """
        return self._hide_signatures

    @hide_signatures.setter
    def hide_signatures(self, hide_signatures):
        """
        Sets the hide_signatures.

        Flag to hide signatures from page preview image. Only signatures are marked as IsSignature will be hidden from generated document page image  # noqa: E501

        :param hide_signatures: The hide_signatures.  # noqa: E501
        :type: bool
        """
        if hide_signatures is None:
            raise ValueError("Invalid value for `hide_signatures`, must not be `None`")  # noqa: E501
        self._hide_signatures = hide_signatures
    
    @property
    def output_path(self):
        """
        Gets the output_path.  # noqa: E501

        Set path for output pages. If not set then default path used.  # noqa: E501

        :return: The output_path.  # noqa: E501
        :rtype: str
        """
        return self._output_path

    @output_path.setter
    def output_path(self, output_path):
        """
        Sets the output_path.

        Set path for output pages. If not set then default path used.  # noqa: E501

        :param output_path: The output_path.  # noqa: E501
        :type: str
        """
        self._output_path = output_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PreviewSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="StampLine.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

class StampLine(object):
    """
    Specify Stamp line properties
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'height': 'int',
        'background_color': 'Color',
        'text': 'str',
        'font': 'SignatureFont',
        'text_color': 'Color',
        'text_bottom_intent': 'int',
        'text_repeat_type': 'str',
        'outer_border': 'BorderLine',
        'inner_border': 'BorderLine',
        'visible': 'bool'
    }

    attribute_map = {
        'height': 'Height',
        'background_color': 'BackgroundColor',
        'text': 'Text',
        'font': 'Font',
        'text_color': 'TextColor',
        'text_bottom_intent': 'TextBottomIntent',
        'text_repeat_type': 'TextRepeatType',
        'outer_border': 'OuterBorder',
        'inner_border': 'InnerBorder',
        'visible': 'Visible'
    }

    def __init__(self, height=None, background_color=None, text=None, font=None, text_color=None, text_bottom_intent=None, text_repeat_type=None, outer_border=None, inner_border=None, visible=None, **kwargs):  # noqa: E501
        """Initializes new instance of StampLine"""  # noqa: E501

        self._height = None
        self._background_color = None
        self._text = None
        self._font = None
        self._text_color = None
        self._text_bottom_intent = None
        self._text_repeat_type = None
        self._outer_border = None
        self._inner_border = None
        self._visible = None

        if height is not None:
            self.height = height
        if background_color is not None:
            self.background_color = background_color
        if text is not None:
            self.text = text
        if font is not None:
            self.font = font
        if text_color is not None:
            self.text_color = text_color
        if text_bottom_intent is not None:
            self.text_bottom_intent = text_bottom_intent
        if text_repeat_type is not None:
            self.text_repeat_type = text_repeat_type
        if outer_border is not None:
            self.outer_border = outer_border
        if inner_border is not None:
            self.inner_border = inner_border
        if visible is not None:
            self.visible = visible
    
    @property
    def height(self):
        """
        Gets the height.  # noqa: E501

        Gets or sets the line height on Stamp  # noqa: E501

        :return: The height.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height.

        Gets or sets the line height on Stamp  # noqa: E501

        :param height: The height.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501
        self._height = height
    
    @property
    def background_color(self):
        """
        Gets the background_color.  # noqa: E501

        Gets or sets the background color of signature  # noqa: E501

        :return: The background_color.  # noqa: E501
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color.

        Gets or sets the background color of signature  # noqa: E501

        :param background_color: The background_color.  # noqa: E501
        :type: Color
        """
        self._background_color = background_color
    
    @property
    def text(self):
        """
        Gets the text.  # noqa: E501

        Gets or sets the text of stamp line  # noqa: E501

        :return: The text.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text.

        Gets or sets the text of stamp line  # noqa: E501

        :param text: The text.  # noqa: E501
        :type: str
        """
        self._text = text
    
    @property
    def font(self):
        """
        Gets the font.  # noqa: E501

        Get or set Font of Stamp Line text  # noqa: E501

        :return: The font.  # noqa: E501
        :rtype: SignatureFont
        """
        return self._font

    @font.setter
    def font(self, font):
        """
        Sets the font.

        Get or set Font of Stamp Line text  # noqa: E501

        :param font: The font.  # noqa: E501
        :type: SignatureFont
        """
        self._font = font
    
    @property
    def text_color(self):
        """
        Gets the text_color.  # noqa: E501

        Gets or sets the text color of signature  # noqa: E501

        :return: The text_color.  # noqa: E501
        :rtype: Color
        """
        return self._text_color

    @text_color.setter
    def text_color(self, text_color):
        """
        Sets the text_color.

        Gets or sets the text color of signature  # noqa: E501

        :param text_color: The text_color.  # noqa: E501
        :type: Color
        """
        self._text_color = text_color
    
    @property
    def text_bottom_intent(self):
        """
        Gets the text_bottom_intent.  # noqa: E501

        Gets or sets the bottom intent of text  # noqa: E501

        :return: The text_bottom_intent.  # noqa: E501
        :rtype: int
        """
        return self._text_bottom_intent

    @text_bottom_intent.setter
    def text_bottom_intent(self, text_bottom_intent):
        """
        Sets the text_bottom_intent.

        Gets or sets the bottom intent of text  # noqa: E501

        :param text_bottom_intent: The text_bottom_intent.  # noqa: E501
        :type: int
        """
        if text_bottom_intent is None:
            raise ValueError("Invalid value for `text_bottom_intent`, must not be `None`")  # noqa: E501
        self._text_bottom_intent = text_bottom_intent
    
    @property
    def text_repeat_type(self):
        """
        Gets the text_repeat_type.  # noqa: E501

        Gets or sets text repeat type  # noqa: E501

        :return: The text_repeat_type.  # noqa: E501
        :rtype: str
        """
        return self._text_repeat_type

    @text_repeat_type.setter
    def text_repeat_type(self, text_repeat_type):
        """
        Sets the text_repeat_type.

        Gets or sets text repeat type  # noqa: E501

        :param text_repeat_type: The text_repeat_type.  # noqa: E501
        :type: str
        """
        if text_repeat_type is None:
            raise ValueError("Invalid value for `text_repeat_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "FullTextRepeat", "RepeatWithTruncation"]  # noqa: E501
        if not text_repeat_type.isdigit():	
            if text_repeat_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_repeat_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_repeat_type, allowed_values))
            self._text_repeat_type = text_repeat_type
        else:
            self._text_repeat_type = allowed_values[int(text_repeat_type) if six.PY3 else long(text_repeat_type)]
    
    @property
    def outer_border(self):
        """
        Gets the outer_border.  # noqa: E501

        Setup Outer Border  # noqa: E501

        :return: The outer_border.  # noqa: E501
        :rtype: BorderLine
        """
        return self._outer_border

    @outer_border.setter
    def outer_border(self, outer_border):
        """
        Sets the outer_border.

        Setup Outer Border  # noqa: E501

        :param outer_border: The outer_border.  # noqa: E501
        :type: BorderLine
        """
        self._outer_border = outer_border
    
    @property
    def inner_border(self):
        """
        Gets the inner_border.  # noqa: E501

        Setup Internal Border  # noqa: E501

        :return: The inner_border.  # noqa: E501
        :rtype: BorderLine
        """
        return self._inner_border

    @inner_border.setter
    def inner_border(self, inner_border):
        """
        Sets the inner_border.

        Setup Internal Border  # noqa: E501

        :param inner_border: The inner_border.  # noqa: E501
        :type: BorderLine
        """
        self._inner_border = inner_border
    
    @property
    def visible(self):
        """
        Gets the visible.  # noqa: E501

        Get and set visibility of Stamp Line  # noqa: E501

        :return: The visible.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """
        Sets the visible.

        Get and set visibility of Stamp Line  # noqa: E501

        :param visible: The visible.  # noqa: E501
        :type: bool
        """
        if visible is None:
            raise ValueError("Invalid value for `visible`, must not be `None`")  # noqa: E501
        self._visible = visible

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StampLine):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="SignDigitalOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignImageOptions

class SignDigitalOptions(SignImageOptions):
    """
    Represents the Digital sign options
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reason': 'str',
        'contact': 'str',
        'location': 'str',
        'visible': 'bool',
        'password': 'str',
        'certificate_file_path': 'str',
        'x_ad_es_type': 'str'
    }

    attribute_map = {
        'reason': 'Reason',
        'contact': 'Contact',
        'location': 'Location',
        'visible': 'Visible',
        'password': 'Password',
        'certificate_file_path': 'CertificateFilePath',
        'x_ad_es_type': 'XAdESType'
    }

    def __init__(self, reason=None, contact=None, location=None, visible=None, password=None, certificate_file_path=None, x_ad_es_type=None, **kwargs):  # noqa: E501
        """Initializes new instance of SignDigitalOptions"""  # noqa: E501

        self._reason = None
        self._contact = None
        self._location = None
        self._visible = None
        self._password = None
        self._certificate_file_path = None
        self._x_ad_es_type = None

        if reason is not None:
            self.reason = reason
        if contact is not None:
            self.contact = contact
        if location is not None:
            self.location = location
        if visible is not None:
            self.visible = visible
        if password is not None:
            self.password = password
        if certificate_file_path is not None:
            self.certificate_file_path = certificate_file_path
        if x_ad_es_type is not None:
            self.x_ad_es_type = x_ad_es_type

        base = super(SignDigitalOptions, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def reason(self):
        """
        Gets the reason.  # noqa: E501

        Gets or sets the reason of signature.  # noqa: E501

        :return: The reason.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason.

        Gets or sets the reason of signature.  # noqa: E501

        :param reason: The reason.  # noqa: E501
        :type: str
        """
        self._reason = reason
    
    @property
    def contact(self):
        """
        Gets the contact.  # noqa: E501

        Gets or sets the signature contact.  # noqa: E501

        :return: The contact.  # noqa: E501
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact.

        Gets or sets the signature contact.  # noqa: E501

        :param contact: The contact.  # noqa: E501
        :type: str
        """
        self._contact = contact
    
    @property
    def location(self):
        """
        Gets the location.  # noqa: E501

        Gets or sets the signature location.  # noqa: E501

        :return: The location.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location.

        Gets or sets the signature location.  # noqa: E501

        :param location: The location.  # noqa: E501
        :type: str
        """
        self._location = location
    
    @property
    def visible(self):
        """
        Gets the visible.  # noqa: E501

        Gets or sets the visibility of signature.  # noqa: E501

        :return: The visible.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """
        Sets the visible.

        Gets or sets the visibility of signature.  # noqa: E501

        :param visible: The visible.  # noqa: E501
        :type: bool
        """
        if visible is None:
            raise ValueError("Invalid value for `visible`, must not be `None`")  # noqa: E501
        self._visible = visible
    
    @property
    def password(self):
        """
        Gets the password.  # noqa: E501

        Gets or sets the password of digital certificate  # noqa: E501

        :return: The password.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password.

        Gets or sets the password of digital certificate  # noqa: E501

        :param password: The password.  # noqa: E501
        :type: str
        """
        self._password = password
    
    @property
    def certificate_file_path(self):
        """
        Gets the certificate_file_path.  # noqa: E501

        Gets or sets the digital certificate file GUID  # noqa: E501

        :return: The certificate_file_path.  # noqa: E501
        :rtype: str
        """
        return self._certificate_file_path

    @certificate_file_path.setter
    def certificate_file_path(self, certificate_file_path):
        """
        Sets the certificate_file_path.

        Gets or sets the digital certificate file GUID  # noqa: E501

        :param certificate_file_path: The certificate_file_path.  # noqa: E501
        :type: str
        """
        self._certificate_file_path = certificate_file_path
    
    @property
    def x_ad_es_type(self):
        """
        Gets the x_ad_es_type.  # noqa: E501

        XAdES type GroupDocs.Signature.Options.DigitalSignOptions.XAdESType. Default value is None (XAdES is off). At this moment XAdES signature type is supported only for Spreadsheet documents.               # noqa: E501

        :return: The x_ad_es_type.  # noqa: E501
        :rtype: str
        """
        return self._x_ad_es_type

    @x_ad_es_type.setter
    def x_ad_es_type(self, x_ad_es_type):
        """
        Sets the x_ad_es_type.

        XAdES type GroupDocs.Signature.Options.DigitalSignOptions.XAdESType. Default value is None (XAdES is off). At this moment XAdES signature type is supported only for Spreadsheet documents.               # noqa: E501

        :param x_ad_es_type: The x_ad_es_type.  # noqa: E501
        :type: str
        """
        if x_ad_es_type is None:
            raise ValueError("Invalid value for `x_ad_es_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "XAdES"]  # noqa: E501
        if not x_ad_es_type.isdigit():	
            if x_ad_es_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `x_ad_es_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(x_ad_es_type, allowed_values))
            self._x_ad_es_type = x_ad_es_type
        else:
            self._x_ad_es_type = allowed_values[int(x_ad_es_type) if six.PY3 else long(x_ad_es_type)]

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignDigitalOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="test_context.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import glob
import json
import os
import tempfile
import unittest
import warnings
import threading
import six

from groupdocs_signature_cloud import Configuration, InfoApi, SignApi, StorageApi, FileApi, FolderApi
from groupdocs_signature_cloud import ObjectExistsRequest, UploadFileRequest, DeleteFolderRequest
from test.test_settings import TestSettings
from test.test_file import TestFile

class TestContext(unittest.TestCase):

    info_api = None
    sign_api = None
    storage_api = None
    file_api = None
    folder_api = None
    _test_files_uploaded = False

    def setUp(self):
        if six.PY3:
            warnings.simplefilter("ignore", ResourceWarning)

        self._init_api()
        self._upload_test_files()

    def tearDown(self):
        self._remove_folder_in_storage("Output")
        self._close_api_thread_pool()

    def get_test_file_path(self, file):
        test_files = "test\\test_files"
        test_file_path = os.path.join(test_files, file.folder, file.file_name) 

        return test_file_path

    def to_json_file(self, obj):
        obj_dict = { obj.attribute_map[attr]: getattr(obj, attr)
                     for attr, _ in six.iteritems(obj.swagger_types)
                     if hasattr(obj, attr) and getattr(obj, attr) is not None }

        json_str = json.dumps(obj_dict)

        temp_file = tempfile.NamedTemporaryFile("w", delete = False)

        json_file = temp_file.file
        json_file.write(json_str)
        json_file.close()

        return temp_file.name

    def _close_api_thread_pool(self):
        self.info_api.close()
        self.sign_api.close()
        self.storage_api.close()
        self.file_api.close()
        self.folder_api.close()

    def _remove_folder_in_storage(self, folder):
        request = DeleteFolderRequest(folder, None, True)
        self.folder_api.delete_folder(request)
        return

    def _upload_test_files(self):
        if TestContext._test_files_uploaded:
            return

        for test_file in TestFile.get_test_files():
            local_file_path = self.get_test_file_path(test_file)
            remote_file_path = test_file.folder + test_file.file_name            
            exist_request = ObjectExistsRequest(remote_file_path)
            response = self.storage_api.object_exists(exist_request)
            if not response.exists:
                print('Upload file: ' + remote_file_path)
                request = UploadFileRequest(remote_file_path, local_file_path)
                self.file_api.upload_file(request)

        TestContext._test_files_uploaded = True

    def _init_api(self):
        if self.sign_api is None:
            configuration = Configuration(TestSettings.APP_SID, TestSettings.APP_KEY)
            configuration.api_base_url = TestSettings.API_BASE_URL
            #configuration.debug = True
            self.info_api = InfoApi.from_config(configuration)
            self.sign_api = SignApi.from_config(configuration)
            self.storage_api = StorageApi.from_config(configuration)
            self.file_api = FileApi.from_config(configuration)
            self.folder_api = FolderApi.from_config(configuration)



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from groupdocs_signature_cloud.auth import Auth
from groupdocs_signature_cloud.api_client import ApiClient
from groupdocs_signature_cloud.api_exception import ApiException
from groupdocs_signature_cloud.configuration import Configuration

class SignApi(object):
    """
    GroupDocs.Signature Cloud API

    :param configuration: API configuration
    """

    def __init__(self, configuration):
        api_client = ApiClient(configuration)

        self.auth = Auth(configuration, api_client)
        self.api_client = api_client
        self.configuration = configuration

    def close(self):  # noqa: E501
        """
        Closes thread pool. This method should be called when 
        methods are executed asynchronously (is_async=True is passed as parameter)
        and this instance of SignApi is not going to be used any more.
        """
        if self.api_client is not None:
            if(self.api_client.pool is not None):
                self.api_client.pool.close()
                self.api_client.pool.join()
                self.api_client.pool = None

    @classmethod
    def from_keys(cls, app_sid, app_key):
        """
        Initializes new instance of SignApi with API keys

        :param app_sid Application identifier (App SID)
        :param app_key Application private key (App Key)
        """
        configuration = Configuration(app_sid, app_key)
        return SignApi(configuration)

    @classmethod
    def from_config(cls, configuration):
        """
        Initializes new instance of SignApi with configuration options

        :param configuration API configuration
        """
        return SignApi(configuration)

    def create_signatures(self, request,**kwargs):  # noqa: E501
        """Creates new signatures in the document and saves resultant document into &#39;Output&#39; folder   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param SignSettings sign_settings: Document sign settings (required)
        :return: SignResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._create_signatures_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._create_signatures_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _create_signatures_with_http_info(self, request, **kwargs):  # noqa: E501
        """Creates new signatures in the document and saves resultant document into &#39;Output&#39; folder   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param CreateSignaturesRequest request object with parameters
        :return: SignResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_signatures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'sign_settings' is set
        if request.sign_settings is None:
            raise ValueError("Missing the required parameter `sign_settings` when calling `create_signatures`")  # noqa: E501

        collection_formats = {}
        path = '/signature/create'
        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        if request.sign_settings is not None:
            body_params = request.sign_settings
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'POST',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'SignResult',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def delete_signatures(self, request,**kwargs):  # noqa: E501
        """Deletes signatures in the document  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param DeleteSettings delete_settings: Delete signatures settings (required)
        :return: DeleteResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._delete_signatures_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._delete_signatures_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _delete_signatures_with_http_info(self, request, **kwargs):  # noqa: E501
        """Deletes signatures in the document  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param DeleteSignaturesRequest request object with parameters
        :return: DeleteResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_signatures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'delete_settings' is set
        if request.delete_settings is None:
            raise ValueError("Missing the required parameter `delete_settings` when calling `delete_signatures`")  # noqa: E501

        collection_formats = {}
        path = '/signature/delete'
        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        if request.delete_settings is not None:
            body_params = request.delete_settings
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'POST',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'DeleteResult',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def search_signatures(self, request,**kwargs):  # noqa: E501
        """Searches for signatures applied to the document  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param SearchSettings search_settings: Signatures search settings (required)
        :return: SearchResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._search_signatures_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._search_signatures_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _search_signatures_with_http_info(self, request, **kwargs):  # noqa: E501
        """Searches for signatures applied to the document  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param SearchSignaturesRequest request object with parameters
        :return: SearchResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_signatures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'search_settings' is set
        if request.search_settings is None:
            raise ValueError("Missing the required parameter `search_settings` when calling `search_signatures`")  # noqa: E501

        collection_formats = {}
        path = '/signature/search'
        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        if request.search_settings is not None:
            body_params = request.search_settings
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'POST',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'SearchResult',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def update_signatures(self, request,**kwargs):  # noqa: E501
        """Updates signatures in the document  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param UpdateSettings update_settings: Update signatures settings (required)
        :return: UpdateResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._update_signatures_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._update_signatures_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _update_signatures_with_http_info(self, request, **kwargs):  # noqa: E501
        """Updates signatures in the document  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param UpdateSignaturesRequest request object with parameters
        :return: UpdateResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_signatures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'update_settings' is set
        if request.update_settings is None:
            raise ValueError("Missing the required parameter `update_settings` when calling `update_signatures`")  # noqa: E501

        collection_formats = {}
        path = '/signature/update'
        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        if request.update_settings is not None:
            body_params = request.update_settings
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'POST',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'UpdateResult',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def verify_signatures(self, request,**kwargs):  # noqa: E501
        """Verifies whether document contains signatures that meet the specified criteria  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param VerifySettings verify_settings: Settings that includes different criteria to verify document signatures (required)
        :return: VerifyResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if kwargs.get('is_async'):
            return self._verify_signatures_with_http_info(request, **kwargs)  # noqa: E501
        
        (data) = self._verify_signatures_with_http_info(request, **kwargs)  # noqa: E501
        return data

    def _verify_signatures_with_http_info(self, request, **kwargs):  # noqa: E501
        """Verifies whether document contains signatures that meet the specified criteria  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True

        :param is_async bool
        :param VerifySignaturesRequest request object with parameters
        :return: VerifyResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        params = locals()
        params['is_async'] = ''
        params['_return_http_data_only'] = False
        params['_preload_content'] = True
        params['_request_timeout'] = ''
        for key, val in six.iteritems(params['kwargs']):
            if key not in params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method verify_signatures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'verify_settings' is set
        if request.verify_settings is None:
            raise ValueError("Missing the required parameter `verify_settings` when calling `verify_signatures`")  # noqa: E501

        collection_formats = {}
        path = '/signature/verify'
        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None
        if request.verify_settings is not None:
            body_params = request.verify_settings
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        call_kwargs = {
            'resource_path':path, 
            'method':'POST',
            'path_params':path_params,
            'query_params':query_params,
            'header_params':header_params,
            'body':body_params,
            'post_params':form_params,
            'files':local_var_files,
            'response_type':'VerifyResult',  # noqa: E501
            'auth_settings':self.auth.get_auth_settings(),
            'is_async':params.get('is_async'),
            '_return_http_data_only':params.get('_return_http_data_only'),
            '_preload_content':params.get('_preload_content', True),
            '_request_timeout':params.get('_request_timeout'),
            'collection_formats':collection_formats
        }

        return self.api_client.call_api(**call_kwargs)  # noqa: E501

    def __downcase_first_letter(self, s):
        if len(s) == 0:
            return str
        else:
            return s[0].lower() + s[1:]

# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="create_signatures_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class CreateSignaturesRequest(object):
    """
    Request model for create_signatures operation.
    :param sign_settings Document sign settings
    """

    def __init__(self, sign_settings):
        """Initializes new instance of CreateSignaturesRequest."""  # noqa: E501
        self.sign_settings = sign_settings
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="delete_signatures_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class DeleteSignaturesRequest(object):
    """
    Request model for delete_signatures operation.
    :param delete_settings Delete signatures settings
    """

    def __init__(self, delete_settings):
        """Initializes new instance of DeleteSignaturesRequest."""  # noqa: E501
        self.delete_settings = delete_settings
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="search_signatures_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class SearchSignaturesRequest(object):
    """
    Request model for search_signatures operation.
    :param search_settings Signatures search settings
    """

    def __init__(self, search_settings):
        """Initializes new instance of SearchSignaturesRequest."""  # noqa: E501
        self.search_settings = search_settings
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="update_signatures_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class UpdateSignaturesRequest(object):
    """
    Request model for update_signatures operation.
    :param update_settings Update signatures settings
    """

    def __init__(self, update_settings):
        """Initializes new instance of UpdateSignaturesRequest."""  # noqa: E501
        self.update_settings = update_settings
# coding: utf-8

# --------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="verify_signatures_request.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------

class VerifySignaturesRequest(object):
    """
    Request model for verify_signatures operation.
    :param verify_settings Settings that includes different criteria to verify document signatures
    """

    def __init__(self, verify_settings):
        """Initializes new instance of VerifySignaturesRequest."""  # noqa: E501
        self.verify_settings = verify_settings



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="PagesSetup.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

class PagesSetup(object):
    """
    Describes special pages of document to process
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_page': 'bool',
        'last_page': 'bool',
        'odd_pages': 'bool',
        'even_pages': 'bool',
        'page_numbers': 'list[int]'
    }

    attribute_map = {
        'first_page': 'FirstPage',
        'last_page': 'LastPage',
        'odd_pages': 'OddPages',
        'even_pages': 'EvenPages',
        'page_numbers': 'PageNumbers'
    }

    def __init__(self, first_page=None, last_page=None, odd_pages=None, even_pages=None, page_numbers=None, **kwargs):  # noqa: E501
        """Initializes new instance of PagesSetup"""  # noqa: E501

        self._first_page = None
        self._last_page = None
        self._odd_pages = None
        self._even_pages = None
        self._page_numbers = None

        if first_page is not None:
            self.first_page = first_page
        if last_page is not None:
            self.last_page = last_page
        if odd_pages is not None:
            self.odd_pages = odd_pages
        if even_pages is not None:
            self.even_pages = even_pages
        if page_numbers is not None:
            self.page_numbers = page_numbers
    
    @property
    def first_page(self):
        """
        Gets the first_page.  # noqa: E501

        Get or set flag to use first document page  # noqa: E501

        :return: The first_page.  # noqa: E501
        :rtype: bool
        """
        return self._first_page

    @first_page.setter
    def first_page(self, first_page):
        """
        Sets the first_page.

        Get or set flag to use first document page  # noqa: E501

        :param first_page: The first_page.  # noqa: E501
        :type: bool
        """
        if first_page is None:
            raise ValueError("Invalid value for `first_page`, must not be `None`")  # noqa: E501
        self._first_page = first_page
    
    @property
    def last_page(self):
        """
        Gets the last_page.  # noqa: E501

        Get or set flag to use last document page  # noqa: E501

        :return: The last_page.  # noqa: E501
        :rtype: bool
        """
        return self._last_page

    @last_page.setter
    def last_page(self, last_page):
        """
        Sets the last_page.

        Get or set flag to use last document page  # noqa: E501

        :param last_page: The last_page.  # noqa: E501
        :type: bool
        """
        if last_page is None:
            raise ValueError("Invalid value for `last_page`, must not be `None`")  # noqa: E501
        self._last_page = last_page
    
    @property
    def odd_pages(self):
        """
        Gets the odd_pages.  # noqa: E501

        Get or set flag to use odd pages of document  # noqa: E501

        :return: The odd_pages.  # noqa: E501
        :rtype: bool
        """
        return self._odd_pages

    @odd_pages.setter
    def odd_pages(self, odd_pages):
        """
        Sets the odd_pages.

        Get or set flag to use odd pages of document  # noqa: E501

        :param odd_pages: The odd_pages.  # noqa: E501
        :type: bool
        """
        if odd_pages is None:
            raise ValueError("Invalid value for `odd_pages`, must not be `None`")  # noqa: E501
        self._odd_pages = odd_pages
    
    @property
    def even_pages(self):
        """
        Gets the even_pages.  # noqa: E501

        Get or set flag to use even pages of document  # noqa: E501

        :return: The even_pages.  # noqa: E501
        :rtype: bool
        """
        return self._even_pages

    @even_pages.setter
    def even_pages(self, even_pages):
        """
        Sets the even_pages.

        Get or set flag to use even pages of document  # noqa: E501

        :param even_pages: The even_pages.  # noqa: E501
        :type: bool
        """
        if even_pages is None:
            raise ValueError("Invalid value for `even_pages`, must not be `None`")  # noqa: E501
        self._even_pages = even_pages
    
    @property
    def page_numbers(self):
        """
        Gets the page_numbers.  # noqa: E501

        Set arbitrary pages of document to use  # noqa: E501

        :return: The page_numbers.  # noqa: E501
        :rtype: list[int]
        """
        return self._page_numbers

    @page_numbers.setter
    def page_numbers(self, page_numbers):
        """
        Sets the page_numbers.

        Set arbitrary pages of document to use  # noqa: E501

        :param page_numbers: The page_numbers.  # noqa: E501
        :type: list[int]
        """
        self._page_numbers = page_numbers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PagesSetup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import unittest
import os

from groupdocs_signature_cloud import *
from test.test_context import TestContext
from test.test_file import TestFile

class TestVerifyCollection(TestContext):

    def test_verify_collection_image(self):
        test_file = TestFile.image_signed()
        settings = self.populate_options_image(test_file)            
        response = self.sign_api.verify_signatures(VerifySignaturesRequest(settings))
        self.check_response(response, test_file)

    def test_verify_collection_pdf(self):
        test_file = TestFile.pdf_signed()
        settings = self.populate_options(test_file)            
        response = self.sign_api.verify_signatures(VerifySignaturesRequest(settings))
        self.check_response(response, test_file)

    def test_verify_collection_presentation(self):
        test_file = TestFile.presentation_signed()
        settings = self.populate_options_image(test_file)            
        response = self.sign_api.verify_signatures(VerifySignaturesRequest(settings))
        self.check_response(response, test_file)

    def test_verify_collection_spreadsheet(self):
        test_file = TestFile.spreadsheet_signed()
        settings = self.populate_options(test_file)            
        response = self.sign_api.verify_signatures(VerifySignaturesRequest(settings))
        self.check_response(response, test_file)

    def test_verify_collection_wordprocessing(self):
        test_file = TestFile.wordprocessing_signed()
        settings = self.populate_options(test_file)            
        response = self.sign_api.verify_signatures(VerifySignaturesRequest(settings))
        self.check_response(response, test_file)                       

    @staticmethod
    def barcode_opts():
        opts = VerifyBarcodeOptions()
        
        opts.signature_type = 'Barcode'
        opts.text = '123456789012'
        opts.barcode_type = 'Code39Standard'
        opts.match_type = 'Contains'

        opts.page = 1
        opts.all_pages = True
        ps = PagesSetup()
        ps.even_pages = False
        ps.first_page = True
        ps.last_page = False
        ps.odd_pages = False
        ps.page_numbers = [1]
        opts.pages_setup = ps

        return opts

    @staticmethod
    def qr_code_opts():
        opts = VerifyQRCodeOptions()
        
        opts.signature_type = 'QRCode'
        opts.text = 'John Smith'
        opts.qr_code_type = 'Aztec'
        opts.match_type = 'Contains'

        opts.page = 1
        opts.all_pages = True
        ps = PagesSetup()
        ps.even_pages = False
        ps.first_page = True
        ps.last_page = False
        ps.odd_pages = False
        ps.page_numbers = [1]
        opts.pages_setup = ps

        return opts

    @staticmethod
    def digital_opts():
        opts = VerifyDigitalOptions()
        
        opts.signature_type = 'Digital'

        opts.page = 1
        opts.all_pages = True
        ps = PagesSetup()
        ps.even_pages = False
        ps.first_page = True
        ps.last_page = False
        ps.odd_pages = False
        ps.page_numbers = [1]
        opts.pages_setup = ps

        return opts        

    @staticmethod
    def text_opts():
        opts = VerifyTextOptions()
        
        opts.signature_type = 'Text'
        opts.text = 'John Smith'
        opts.match_type = 'Contains'

        opts.page = 1
        opts.all_pages = True
        ps = PagesSetup()
        ps.even_pages = False
        ps.first_page = True
        ps.last_page = False
        ps.odd_pages = False
        ps.page_numbers = [1]
        opts.pages_setup = ps

        return opts         

    @staticmethod
    def populate_options_image(testFile):
        settings = VerifySettings()
        settings.file_info = testFile.ToFileInfo()        
        settings.options = [TestVerifyCollection.barcode_opts(),
                            TestVerifyCollection.qr_code_opts()]
        return settings

    @staticmethod
    def populate_options(testFile):
        settings = VerifySettings()
        settings.file_info = testFile.ToFileInfo()
        settings.options = [TestVerifyCollection.barcode_opts(),
                            TestVerifyCollection.qr_code_opts(),
                            TestVerifyCollection.digital_opts(),
                            TestVerifyCollection.text_opts()]
        return settings        
    
    def check_response(self, response, test_file):
        self.assertTrue(response)
        self.assertTrue(response.file_info)
        self.assertEqual(response.file_info.file_path, test_file.FilePath())     


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="SignBarcodeOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignTextOptions

class SignBarcodeOptions(SignTextOptions):
    """
    Represents the Barcode signature options
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'barcode_type': 'str',
        'transparency': 'float',
        'code_text_alignment': 'str',
        'inner_margins': 'Padding'
    }

    attribute_map = {
        'barcode_type': 'BarcodeType',
        'transparency': 'Transparency',
        'code_text_alignment': 'CodeTextAlignment',
        'inner_margins': 'InnerMargins'
    }

    def __init__(self, barcode_type=None, transparency=None, code_text_alignment=None, inner_margins=None, **kwargs):  # noqa: E501
        """Initializes new instance of SignBarcodeOptions"""  # noqa: E501

        self._barcode_type = None
        self._transparency = None
        self._code_text_alignment = None
        self._inner_margins = None

        if barcode_type is not None:
            self.barcode_type = barcode_type
        if transparency is not None:
            self.transparency = transparency
        if code_text_alignment is not None:
            self.code_text_alignment = code_text_alignment
        if inner_margins is not None:
            self.inner_margins = inner_margins

        base = super(SignBarcodeOptions, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def barcode_type(self):
        """
        Gets the barcode_type.  # noqa: E501

        Get or set Barcode type. Pick one from supported barcode types list  # noqa: E501

        :return: The barcode_type.  # noqa: E501
        :rtype: str
        """
        return self._barcode_type

    @barcode_type.setter
    def barcode_type(self, barcode_type):
        """
        Sets the barcode_type.

        Get or set Barcode type. Pick one from supported barcode types list  # noqa: E501

        :param barcode_type: The barcode_type.  # noqa: E501
        :type: str
        """
        self._barcode_type = barcode_type
    
    @property
    def transparency(self):
        """
        Gets the transparency.  # noqa: E501

        Gets or sets the signature transparency (value from 0.0 (opaque) through 1.0 (clear)). Default value is 0 (opaque).  # noqa: E501

        :return: The transparency.  # noqa: E501
        :rtype: float
        """
        return self._transparency

    @transparency.setter
    def transparency(self, transparency):
        """
        Sets the transparency.

        Gets or sets the signature transparency (value from 0.0 (opaque) through 1.0 (clear)). Default value is 0 (opaque).  # noqa: E501

        :param transparency: The transparency.  # noqa: E501
        :type: float
        """
        self._transparency = transparency
    
    @property
    def code_text_alignment(self):
        """
        Gets the code_text_alignment.  # noqa: E501

        Gets or sets the alignment of text in the result Barcode Default value is None  # noqa: E501

        :return: The code_text_alignment.  # noqa: E501
        :rtype: str
        """
        return self._code_text_alignment

    @code_text_alignment.setter
    def code_text_alignment(self, code_text_alignment):
        """
        Sets the code_text_alignment.

        Gets or sets the alignment of text in the result Barcode Default value is None  # noqa: E501

        :param code_text_alignment: The code_text_alignment.  # noqa: E501
        :type: str
        """
        if code_text_alignment is None:
            raise ValueError("Invalid value for `code_text_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Above", "Below", "Right"]  # noqa: E501
        if not code_text_alignment.isdigit():	
            if code_text_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `code_text_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(code_text_alignment, allowed_values))
            self._code_text_alignment = code_text_alignment
        else:
            self._code_text_alignment = allowed_values[int(code_text_alignment) if six.PY3 else long(code_text_alignment)]
    
    @property
    def inner_margins(self):
        """
        Gets the inner_margins.  # noqa: E501

        Gets or sets the space between Barcode elements and result image borders  # noqa: E501

        :return: The inner_margins.  # noqa: E501
        :rtype: Padding
        """
        return self._inner_margins

    @inner_margins.setter
    def inner_margins(self, inner_margins):
        """
        Sets the inner_margins.

        Gets or sets the space between Barcode elements and result image borders  # noqa: E501

        :param inner_margins: The inner_margins.  # noqa: E501
        :type: Padding
        """
        self._inner_margins = inner_margins

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignBarcodeOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="DeleteOptions.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

class DeleteOptions(object):
    """
    Base container class for delete signature options
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'signature_type': 'str',
        'signature_id': 'str'
    }

    attribute_map = {
        'signature_type': 'SignatureType',
        'signature_id': 'SignatureId'
    }

    def __init__(self, signature_type=None, signature_id=None, **kwargs):  # noqa: E501
        """Initializes new instance of DeleteOptions"""  # noqa: E501

        self._signature_type = None
        self._signature_id = None

        if signature_type is not None:
            self.signature_type = signature_type
        if signature_id is not None:
            self.signature_id = signature_id
    
    @property
    def signature_type(self):
        """
        Gets the signature_type.  # noqa: E501

        Specifies the type of signature  # noqa: E501

        :return: The signature_type.  # noqa: E501
        :rtype: str
        """
        return self._signature_type

    @signature_type.setter
    def signature_type(self, signature_type):
        """
        Sets the signature_type.

        Specifies the type of signature  # noqa: E501

        :param signature_type: The signature_type.  # noqa: E501
        :type: str
        """
        if signature_type is None:
            raise ValueError("Invalid value for `signature_type`, must not be `None`")  # noqa: E501
        allowed_values = ["None", "Text", "Image", "Digital", "Barcode", "QRCode", "Stamp", "FormField", "Metadata"]  # noqa: E501
        if not signature_type.isdigit():	
            if signature_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `signature_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(signature_type, allowed_values))
            self._signature_type = signature_type
        else:
            self._signature_type = allowed_values[int(signature_type) if six.PY3 else long(signature_type)]
    
    @property
    def signature_id(self):
        """
        Gets the signature_id.  # noqa: E501

        Unique signature identifier to modify signature in the document over Update or Delete methods. This property will be set automatically after Sign or Search method being called. If this property was saved before it can be set manually to manipulate the signature.                # noqa: E501

        :return: The signature_id.  # noqa: E501
        :rtype: str
        """
        return self._signature_id

    @signature_id.setter
    def signature_id(self, signature_id):
        """
        Sets the signature_id.

        Unique signature identifier to modify signature in the document over Update or Delete methods. This property will be set automatically after Sign or Search method being called. If this property was saved before it can be set manually to manipulate the signature.                # noqa: E501

        :param signature_id: The signature_id.  # noqa: E501
        :type: str
        """
        self._signature_id = signature_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis
from groupdocs_signature_cloud.apis.file_api import FileApi
from groupdocs_signature_cloud.apis.folder_api import FolderApi
from groupdocs_signature_cloud.apis.info_api import InfoApi
from groupdocs_signature_cloud.apis.license_api import LicenseApi
from groupdocs_signature_cloud.apis.preview_api import PreviewApi
from groupdocs_signature_cloud.apis.sign_api import SignApi
from groupdocs_signature_cloud.apis.storage_api import StorageApi



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="auth.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import six
import datetime

from groupdocs_signature_cloud.api_client import ApiClient 

class Auth(object):
    """
    API authorization

    :param configuration: API configuration
    :param api_client: API client
    """

    def __init__(self, configuration, api_client):
        self.configuration = configuration
        self.api_client = api_client
        self._access_token = None

    def get_auth_settings(self):
        access_token = self._get_access_token()        

        auth_settings = {
            'type': 'oauth2',
            'in': 'header',
            'key': 'Authorization',
            'value': 'Bearer ' + access_token
        }

        return auth_settings

    def _get_access_token(self):
        if self._access_token is None:
            self._request_access_token()
           
        return self._access_token

    def _request_access_token(self):
        request_url = "/connect/token"
        header_params = {
            'Accept': 'application/json', 
            'Content-Type': 'application/x-www-form-urlencoded'
        }
        form_params = [
            ('grant_type', 'client_credentials'), 
            ('client_id', self.configuration.app_sid),
            ('client_secret', self.configuration.app_key)
        ]
        
        data = self.api_client.call_api(
            resource_path = request_url, 
            method = 'POST',
            header_params = header_params,
            post_params = form_params,
            response_type = 'object',
            _return_http_data_only = True,
            _append_api_version = False
        )

        self._update_tokens(data)    

    def _update_tokens(self, data):
        self._access_token = data['access_token'] if six.PY3 else data['access_token'].encode('utf8')



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="DigitalSignatureAppearance.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from groupdocs_signature_cloud.models import SignatureAppearance

class DigitalSignatureAppearance(SignatureAppearance):
    """
    Describes appearance of Signature Line for Digital Signature. One Signature Line could be applied for only one Digital Signature. Signature Line always is on the first page. This feature may be useful for .docx, .doc, .odt and .xlsx file formats.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'signer': 'str',
        'title': 'str'
    }

    attribute_map = {
        'email': 'Email',
        'signer': 'Signer',
        'title': 'Title'
    }

    def __init__(self, email=None, signer=None, title=None, **kwargs):  # noqa: E501
        """Initializes new instance of DigitalSignatureAppearance"""  # noqa: E501

        self._email = None
        self._signer = None
        self._title = None

        if email is not None:
            self.email = email
        if signer is not None:
            self.signer = signer
        if title is not None:
            self.title = title

        base = super(DigitalSignatureAppearance, self)
        base.__init__(**kwargs)

        self.swagger_types.update(base.swagger_types)
        self.attribute_map.update(base.attribute_map)
    
    @property
    def email(self):
        """
        Gets the email.  # noqa: E501

        Gets or sets a email that will be displayed in signature line.  # noqa: E501

        :return: The email.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email.

        Gets or sets a email that will be displayed in signature line.  # noqa: E501

        :param email: The email.  # noqa: E501
        :type: str
        """
        self._email = email
    
    @property
    def signer(self):
        """
        Gets the signer.  # noqa: E501

        Gets or sets signer name for signature line.  # noqa: E501

        :return: The signer.  # noqa: E501
        :rtype: str
        """
        return self._signer

    @signer.setter
    def signer(self, signer):
        """
        Sets the signer.

        Gets or sets signer name for signature line.  # noqa: E501

        :param signer: The signer.  # noqa: E501
        :type: str
        """
        self._signer = signer
    
    @property
    def title(self):
        """
        Gets the title.  # noqa: E501

        Gets or sets a title for signature line.  # noqa: E501

        :return: The title.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title.

        Gets or sets a title for signature line.  # noqa: E501

        :param title: The title.  # noqa: E501
        :type: str
        """
        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DigitalSignatureAppearance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="api_exception.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import json

class ApiException(Exception):
    """
    API exception
    """

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.code = http_resp.status

            try:
                data = json.loads(http_resp.data)
                
                error = data.get("error")
                
                if error is not None:
                    self.message = error if type(error) is str else error.get("message")                 
                else:
                    message = data.get("message")
                    if message is not None:
                        self.message = message
                        self.code = data.get("code")
                    else:
                        self.message = http_resp.data   
            except ValueError:
                self.message = http_resp.data
        else:
            self.code = status
            self.message = reason

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Message: {1}\n".format(self.code, self.message)

        return error_message



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="BorderLine.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

class BorderLine(object):
    """
    Instance to keep Border line properties
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'style': 'str',
        'transparency': 'float',
        'weight': 'float',
        'color': 'Color',
        'visible': 'bool'
    }

    attribute_map = {
        'style': 'Style',
        'transparency': 'Transparency',
        'weight': 'Weight',
        'color': 'Color',
        'visible': 'Visible'
    }

    def __init__(self, style=None, transparency=None, weight=None, color=None, visible=None, **kwargs):  # noqa: E501
        """Initializes new instance of BorderLine"""  # noqa: E501

        self._style = None
        self._transparency = None
        self._weight = None
        self._color = None
        self._visible = None

        if style is not None:
            self.style = style
        if transparency is not None:
            self.transparency = transparency
        if weight is not None:
            self.weight = weight
        if color is not None:
            self.color = color
        if visible is not None:
            self.visible = visible
    
    @property
    def style(self):
        """
        Gets the style.  # noqa: E501

        Gets or sets the signature border style  # noqa: E501

        :return: The style.  # noqa: E501
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style):
        """
        Sets the style.

        Gets or sets the signature border style  # noqa: E501

        :param style: The style.  # noqa: E501
        :type: str
        """
        if style is None:
            raise ValueError("Invalid value for `style`, must not be `None`")  # noqa: E501
        allowed_values = ["Solid", "ShortDash", "ShortDot", "ShortDashDot", "ShortDashDotDot", "Dot", "Dash", "LongDash", "DashDot", "LongDashDot", "LongDashDotDot", "RoundDot", "SquareDot", "DashDotDot", "DashLongDash", "DashLongDashDot"]  # noqa: E501
        if not style.isdigit():	
            if style not in allowed_values:
                raise ValueError(
                    "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                    .format(style, allowed_values))
            self._style = style
        else:
            self._style = allowed_values[int(style) if six.PY3 else long(style)]
    
    @property
    def transparency(self):
        """
        Gets the transparency.  # noqa: E501

        Gets or sets the signature border transparency (value from 0.0 (opaque) through 1.0 (clear))  # noqa: E501

        :return: The transparency.  # noqa: E501
        :rtype: float
        """
        return self._transparency

    @transparency.setter
    def transparency(self, transparency):
        """
        Sets the transparency.

        Gets or sets the signature border transparency (value from 0.0 (opaque) through 1.0 (clear))  # noqa: E501

        :param transparency: The transparency.  # noqa: E501
        :type: float
        """
        if transparency is None:
            raise ValueError("Invalid value for `transparency`, must not be `None`")  # noqa: E501
        self._transparency = transparency
    
    @property
    def weight(self):
        """
        Gets the weight.  # noqa: E501

        Gets or sets the weight of the signature border  # noqa: E501

        :return: The weight.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """
        Sets the weight.

        Gets or sets the weight of the signature border  # noqa: E501

        :param weight: The weight.  # noqa: E501
        :type: float
        """
        if weight is None:
            raise ValueError("Invalid value for `weight`, must not be `None`")  # noqa: E501
        self._weight = weight
    
    @property
    def color(self):
        """
        Gets the color.  # noqa: E501

        Gets or sets the border color of signature  # noqa: E501

        :return: The color.  # noqa: E501
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color.

        Gets or sets the border color of signature  # noqa: E501

        :param color: The color.  # noqa: E501
        :type: Color
        """
        self._color = color
    
    @property
    def visible(self):
        """
        Gets the visible.  # noqa: E501

        Gets or sets the border visibility  # noqa: E501

        :return: The visible.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """
        Sets the visible.

        Gets or sets the border visibility  # noqa: E501

        :param visible: The visible.  # noqa: E501
        :type: bool
        """
        if visible is None:
            raise ValueError("Invalid value for `visible`, must not be `None`")  # noqa: E501
        self._visible = visible

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BorderLine):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose Pty Ltd" file="PdfDigitalSignature.py">
#   Copyright (c) 2003-2022 Aspose Pty Ltd
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

class PdfDigitalSignature(object):
    """
    Contains pdf digital Signature properties
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contact_info': 'str',
        'location': 'str',
        'reason': 'str',
        'type': 'str',
        'time_stamp': 'TimeStamp',
        'show_properties': 'bool'
    }

    attribute_map = {
        'contact_info': 'ContactInfo',
        'location': 'Location',
        'reason': 'Reason',
        'type': 'Type',
        'time_stamp': 'TimeStamp',
        'show_properties': 'ShowProperties'
    }

    def __init__(self, contact_info=None, location=None, reason=None, type=None, time_stamp=None, show_properties=None, **kwargs):  # noqa: E501
        """Initializes new instance of PdfDigitalSignature"""  # noqa: E501

        self._contact_info = None
        self._location = None
        self._reason = None
        self._type = None
        self._time_stamp = None
        self._show_properties = None

        if contact_info is not None:
            self.contact_info = contact_info
        if location is not None:
            self.location = location
        if reason is not None:
            self.reason = reason
        if type is not None:
            self.type = type
        if time_stamp is not None:
            self.time_stamp = time_stamp
        if show_properties is not None:
            self.show_properties = show_properties
    
    @property
    def contact_info(self):
        """
        Gets the contact_info.  # noqa: E501

        Information provided by the signer to enable a recipient to contact the signer  # noqa: E501

        :return: The contact_info.  # noqa: E501
        :rtype: str
        """
        return self._contact_info

    @contact_info.setter
    def contact_info(self, contact_info):
        """
        Sets the contact_info.

        Information provided by the signer to enable a recipient to contact the signer  # noqa: E501

        :param contact_info: The contact_info.  # noqa: E501
        :type: str
        """
        self._contact_info = contact_info
    
    @property
    def location(self):
        """
        Gets the location.  # noqa: E501

        The CPU host name or physical location of the signing.  # noqa: E501

        :return: The location.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location.

        The CPU host name or physical location of the signing.  # noqa: E501

        :param location: The location.  # noqa: E501
        :type: str
        """
        self._location = location
    
    @property
    def reason(self):
        """
        Gets the reason.  # noqa: E501

        The reason for the signing, such as (I agreeРІР‚В¦).  # noqa: E501

        :return: The reason.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason.

        The reason for the signing, such as (I agreeРІР‚В¦).  # noqa: E501

        :param reason: The reason.  # noqa: E501
        :type: str
        """
        self._reason = reason
    
    @property
    def type(self):
        """
        Gets the type.  # noqa: E501

        Type of Pdf digital signature.  # noqa: E501

        :return: The type.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type.

        Type of Pdf digital signature.  # noqa: E501

        :param type: The type.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["Signature", "Certificate"]  # noqa: E501
        if not type.isdigit():	
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values))
            self._type = type
        else:
            self._type = allowed_values[int(type) if six.PY3 else long(type)]
    
    @property
    def time_stamp(self):
        """
        Gets the time_stamp.  # noqa: E501

        Time stamp for Pdf digital signature. Default value is null.  # noqa: E501

        :return: The time_stamp.  # noqa: E501
        :rtype: TimeStamp
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        """
        Sets the time_stamp.

        Time stamp for Pdf digital signature. Default value is null.  # noqa: E501

        :param time_stamp: The time_stamp.  # noqa: E501
        :type: TimeStamp
        """
        if time_stamp is None:
            raise ValueError("Invalid value for `time_stamp`, must not be `None`")  # noqa: E501
        self._time_stamp = time_stamp
    
    @property
    def show_properties(self):
        """
        Gets the show_properties.  # noqa: E501

        Force to show/hide signature properties  # noqa: E501

        :return: The show_properties.  # noqa: E501
        :rtype: bool
        """
        return self._show_properties

    @show_properties.setter
    def show_properties(self, show_properties):
        """
        Sets the show_properties.

        Force to show/hide signature properties  # noqa: E501

        :param show_properties: The show_properties.  # noqa: E501
        :type: bool
        """
        if show_properties is None:
            raise ValueError("Invalid value for `show_properties`, must not be `None`")  # noqa: E501
        self._show_properties = show_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfDigitalSignature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

import sys
import datetime

from setuptools import setup, find_packages  # noqa: H301

NAME = "groupdocs-signature-cloud"
VERSION = "22.6"

# Append current time to the version when publishing to test environment
if "--test" in sys.argv:
    VERSION += "." + datetime.datetime.now().strftime("%Y%m%d%H%M")
    sys.argv.remove("--test")

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
TEST_REQUIRES = []

with open("README.md", "r") as fh:
    long_description = fh.read()
    
setup(
    name=NAME,
    version=VERSION,
    description="GroupDocs.Signature Cloud Python SDK",
	author="GroupDocs",
    author_email="support@groupdocs.cloud",
    url="http://github.com/groupdocs-signature-cloud/groupdocs-signature-cloud-python",
	classifiers=[
		"Development Status :: 5 - Production/Stable",
		"Intended Audience :: Developers",
		"Topic :: Software Development :: Libraries",
		"License :: OSI Approved :: MIT License",
		"Programming Language :: Python :: 2.7",
		"Programming Language :: Python :: 3.4",
		"Programming Language :: Python :: 3.5",
		"Programming Language :: Python :: 3.6",
		"Programming Language :: Python :: 3.7",
	],
    keywords=["groupdocs", "signature", "cloud", "python", "sdk"],
    install_requires=REQUIRES,
	tests_require=TEST_REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
)
